@@ -14,10 +14,7 @@ from stonewave.sql.udtfs.protocol.fsm.result_batch_sender import (
 )
 from pydantic import BaseModel
 from typing import Optional
-from stonewave.sql.udtfs.protocol.shared_memory_record_batch_reader import (
-    SharedMemoryRecordBatchReader,
-)
-import gc
+import threading
 
 
 class ResponseObj(BaseModel):
@@ -27,8 +24,8 @@ class ResponseObj(BaseModel):
 
 
 def execute_child_worker(func_name, recv_queue, send_queue):
-    def respond(result, error=None):
-        res = json.dumps({"result": result, "error": error})
+    def respond(result, error=None, state=None):
+        res = json.dumps({"result": result, "error": error, "state": state})
         logger.debug("send response", function=func_name, response=res)
         send_queue.put(res)
         send_queue.join()
@@ -47,6 +44,7 @@ def execute_child_worker(func_name, recv_queue, send_queue):
             respond(
                 result="finish",
                 error="function not found, name is {}".format(func_name),
+                state="finish",
             )
             return
 
@@ -64,28 +62,28 @@ def execute_child_worker(func_name, recv_queue, send_queue):
 
             if fsm is None:
                 if method == "apply":
-                    fsm = ApplyFunctionFsm(func, batch_sender)
+                    fsm = ApplyFunctionFsm(func, batch_sender, respond)
                 elif method == "eval":
-                    fsm = EvalFunctionFsm(func, batch_sender)
+                    fsm = EvalFunctionFsm(func, batch_sender, respond)
                 elif method == "eval_with_table_param":
-                    fsm = EvalFunctionWithTableParamFsm(func, batch_sender)
+                    fsm = EvalFunctionWithTableParamFsm(func, batch_sender, respond)
             fsm_trigger = getattr(fsm, method, None)
             if fsm_trigger:
                 try:
-                    fsm_trigger(params, respond)
+                    fsm_trigger(params)
                 except Exception as e:
                     logger.error("error occurred during function execution", error=str(e))
                     params = None
                     request = None
                     fsm._clean_up()
-                    respond(result="finish", error=e.args[0])
+                    respond(result="finish", error=e.args[0], state="finish")
                     break
                 logger.debug("finish executing request", function=func_name, state=fsm.state)
                 if fsm.is_end():
-                    logger.info("finish function execution", function=func_name)
+                    logger.debug("finish function execution", function=func_name)
                     break
             else:
-                respond(result="finish", error="invalid_method=" + method)
+                respond(result="finish", error="invalid_method=" + method, state="finish")
                 break
         if func_sys_path in sys.path:
             sys.path.remove(func_sys_path)
@@ -93,7 +91,7 @@ def execute_child_worker(func_name, recv_queue, send_queue):
             sys.path.remove(USER_DEFINED_TABLE_FUNCTIONS_PATH)
     except Exception as e:
         logger.error("error occured", error=str(e))
-        respond("finish", error=str(e))
+        respond("finish", error=str(e), state="finish")
     finally:
         fsm = None
         batch_sender = None
@@ -102,67 +100,11 @@ def execute_child_worker(func_name, recv_queue, send_queue):
 
 
 def execute_worker(func_name, recv_queue, send_queue):
-    execute_child_worker(func_name, recv_queue, send_queue)
-    ## unlink shared memory objects to release memory
-    gc.collect()
-    SharedMemoryRecordBatchReader.shared_memory_objects = []
-
-
-# this protocol roughly follows json-rpc protocol's request/response format
-# stdin/stdout is used as transport (in_func/out_io)
-# https://en.wikipedia.org/wiki/JSON-RPC
-# a request contains three properties: method, params, id
-# a response contains three properties: result, error, id
-def execute(func_name, in_func, out_io):
-    sys.path.append(USER_DEFINED_TABLE_FUNCTIONS_PATH)
-    sys.path.append(os.path.join(USER_DEFINED_TABLE_FUNCTIONS_PATH, func_name))
-    logger.info("start function execution", function=func_name)
-    sys.path.append(os.path.join(USER_DEFINED_TABLE_FUNCTIONS_PATH, func_name))
-    function = load_function_by_name(func_name)
-    func = function()
-
-    fsm = None
-    batch_sender = SharedMemoryRecordBatchSender()
-
-    while True:
-        logger.debug("waiting for request", function=func_name)
-        command = in_func()
-        logger.debug("receive request", function=func_name, request=command)
-        request = json.loads(command)
-        method, params, request_id = request["method"], request["params"], request["id"]
-
-        def respond(result, error=None):
-            res = json.dumps({"result": result, "error": error, "id": request_id})
-            logger.debug("send response", function=func_name, response=res)
-            print(
-                res,
-                file=out_io,
-                flush=True,
-            )
-
-        if fsm is None:
-            if method == "apply":
-                fsm = ApplyFunctionFsm(func, batch_sender)
-            elif method == "eval":
-                fsm = EvalFunctionFsm(func, batch_sender)
-            elif method == "eval_with_table_param":
-                fsm = EvalFunctionWithTableParamFsm(func, batch_sender)
-        fsm_trigger = getattr(fsm, method, None)
-        if fsm_trigger:
-            try:
-                fsm_trigger(params, respond)
-            except Exception as e:
-                logger.error("error occurred during function execution", error=str(e))
-                respond(result=None, error=e.args[0])
-                break
-            logger.debug("finish executing request", function=func_name, state=fsm.state)
-            if fsm.is_end():
-                logger.info("finish function execution", function=func_name)
-                break
-        else:
-            respond(result=None, error="invalid_method=" + method)
-
-
-if __name__ == "__main__":
-    func_name = sys.argv[1]
-    execute(func_name, input, sys.stdout)
+    thread = threading.Thread(target=execute_child_worker, args=(func_name, recv_queue, send_queue))
+    thread.start()
+    logger.info(
+        "start executing function",
+        function=func_name,
+        thread_id=thread.ident,
+        thread_native_id=thread.native_id,
+    )
