@@ -2,7 +2,6 @@ from faker import Faker
 import pyarrow as pa
 from faker_web import WebProvider
 from faker_vehicle import VehicleProvider
-from faker_wifi_essid import WifiESSID as WifiEssidProvider
 from faker_microservice import Provider as MicroServiceProvider
 from faker_credit_score import CreditScore as CreditScoreProvider
 import decimal
@@ -11,7 +10,6 @@ from stonewave.sql.udtfs.logger import logger
 
 fake = Faker()
 fake.add_provider(WebProvider)
-fake.add_provider(WifiEssidProvider)
 fake.add_provider(MicroServiceProvider)
 fake.add_provider(VehicleProvider)
 fake.add_provider(CreditScoreProvider)
