@@ -19,10 +19,10 @@ class ParseBinaryFunction(BaseFunction):
     def get_name(self):
         return "parse_binary"
 
-    def process(self, row_writer, row_idx, args):
-        file_path = args[0]
-        format_name = args[1]
-        data_paths = [c.strip() for c in args[2].split(",")] if len(args) > 2 else []
+    def process(self, params, table_writer, context):
+        file_path = params[0]
+        format_name = params[1]
+        data_paths = [c.strip() for c in params[2].split(",")] if len(params) > 2 else []
         kaitai_parser = "stonewave.sql.udtfs.functions.parse_binary.formats.{}".format(format_name)
         module = importlib.import_module(kaitai_parser)
         parser_class_name = _to_camel_case(format_name)
@@ -34,4 +34,4 @@ class ParseBinaryFunction(BaseFunction):
             # TODO: can we marshall it into a JSON string?
             value = str(getattr(parsed_binary, path))
             kv_pairs[path] = value
-        row_writer.record_batch_builder.append_row(kv_pairs)
+        table_writer.write_row(kv_pairs)
