@@ -27,7 +27,7 @@ class JavaClass(KaitaiStruct):
     def _read(self):
         self.magic = self._io.read_bytes(4)
         if not self.magic == b"\xCA\xFE\xBA\xBE":
-            raise kaitaistruct.ValidationNotEqualError(b"\xCA\xFE\xBA\xBE", self.magic, self._io, u"/seq/0")
+            raise kaitaistruct.ValidationNotEqualError(b"\xCA\xFE\xBA\xBE", self.magic, self._io, "/seq/0")
         self.version_minor = self._io.read_u2be()
         self.version_major = self._io.read_u2be()
         self.constant_pool_count = self._io.read_u2be()
@@ -89,19 +89,19 @@ class JavaClass(KaitaiStruct):
             self.name_index = self._io.read_u2be()
             self.attribute_length = self._io.read_u4be()
             _on = self.name_as_str
-            if _on == u"SourceFile":
+            if _on == "SourceFile":
                 self._raw_info = self._io.read_bytes(self.attribute_length)
                 _io__raw_info = KaitaiStream(BytesIO(self._raw_info))
                 self.info = JavaClass.AttributeInfo.AttrBodySourceFile(_io__raw_info, self, self._root)
-            elif _on == u"LineNumberTable":
+            elif _on == "LineNumberTable":
                 self._raw_info = self._io.read_bytes(self.attribute_length)
                 _io__raw_info = KaitaiStream(BytesIO(self._raw_info))
                 self.info = JavaClass.AttributeInfo.AttrBodyLineNumberTable(_io__raw_info, self, self._root)
-            elif _on == u"Exceptions":
+            elif _on == "Exceptions":
                 self._raw_info = self._io.read_bytes(self.attribute_length)
                 _io__raw_info = KaitaiStream(BytesIO(self._raw_info))
                 self.info = JavaClass.AttributeInfo.AttrBodyExceptions(_io__raw_info, self, self._root)
-            elif _on == u"Code":
+            elif _on == "Code":
                 self._raw_info = self._io.read_bytes(self.attribute_length)
                 _io__raw_info = KaitaiStream(BytesIO(self._raw_info))
                 self.info = JavaClass.AttributeInfo.AttrBodyCode(_io__raw_info, self, self._root)
@@ -471,7 +471,7 @@ class JavaClass(KaitaiStruct):
 
         def _read(self):
             self.str_len = self._io.read_u2be()
-            self.value = (self._io.read_bytes(self.str_len)).decode(u"UTF-8")
+            self.value = (self._io.read_bytes(self.str_len)).decode("UTF-8")
 
     class StringCpInfo(KaitaiStruct):
         """
