@@ -11,9 +11,9 @@ class ParseGrokFunction(BaseFunction):
     def get_name(self):
         return "parse_grok"
 
-    def process(self, row_writer, row_idx, args):
-        text = args[0]
-        grok_pattern = args[1]
+    def process(self, params, table_writer, context):
+        text = params[0]
+        grok_pattern = params[1]
 
         grok = None
         if grok_pattern in self.grok_pattern_cache:
@@ -23,10 +23,7 @@ class ParseGrokFunction(BaseFunction):
             self.grok_pattern_cache[grok_pattern] = grok
         extracted_values = grok.match(text)
 
-        record_batch_builder = row_writer.record_batch_builder
         if extracted_values:
             for col_name, col_value in extracted_values.items():
                 # FIXME: support more non string data types
-                record_batch_builder.add_column(col_name, pa.utf8())
-                record_batch_builder.append(col_name, col_value)
-            record_batch_builder.increase_row_count()
+                table_writer.write_column(col_name, pa.utf8(), [col_value])
