@@ -9,17 +9,17 @@ class SummarizeFunction(BaseFunction):
     def get_name(self):
         return "summarize"
 
-    def process(self, row_writer, row_idx, args):
-        assert len(args) > 0
-        batch = args[0]
+    def process(self, params, table_writer, context):
+        assert len(params) > 0
+        batch = params[0]
         if batch is not None:
             table = pa.Table.from_batches([batch])
             # FIXME: the current implementation caches all batches, which is not necessary
             self.tables.append(table)
         else:
-            self.summarize(row_writer)
+            self.summarize(table_writer)
 
-    def summarize(self, row_writer):
+    def summarize(self, table_writer):
         if self.tables:
             table = pa.concat_tables(self.tables, promote=True)
             df = table.to_pandas()
@@ -29,6 +29,6 @@ class SummarizeFunction(BaseFunction):
             desc_df.insert(0, "fields", desc_df.index)
             desc_table = pa.Table.from_pandas(desc_df, preserve_index=False)
             batches = desc_table.to_batches()
-            row_writer.batch_iterator = iter(batches)
+            table_writer.table_batch_iterator = iter(batches)
         else:
             return
