@@ -18,7 +18,7 @@ def load_function_by_name(name):
     try:
         # built-in table functions
         lib = importlib.import_module("stonewave.sql.udtfs.functions.{}".format(name))
-        logger.info("load built-in table function", function_name=name)
+        logger.debug("load built-in table function", function_name=name)
         return _find_base_function_from_lib(lib)
     except:
         try:
@@ -26,14 +26,16 @@ def load_function_by_name(name):
             # functions path has been append to sys.path when starting the executor
 
             lib = importlib.import_module(name)
-            logger.info("load user defined table function", function_name=name)
+            logger.debug("load user defined table function", function_name=name)
             return _find_base_function_from_lib(lib)
         except:
             try:
                 importlib.invalidate_caches()
                 lib = importlib.import_module(name)
-                logger.info("clean cache and load user defined table function", function_name=name)
+                logger.info(
+                    "clean cache and load user defined table function",
+                    function_name=name,
+                )
                 return _find_base_function_from_lib(lib)
             except Exception as e:
-                logger.error("function not found", function_name=name, error=str(e))
-                return None
+                raise Exception("Failed to load function '{}': {}".format(name, str(e)))
