@@ -10,8 +10,9 @@ from structlog.contextvars import (
 )
 
 
-LOG_LEVEL = os.getenv("SW_LOG_LEVEL") or "INFO"
+LOG_LEVEL = os.getenv("STONEWAVE_LOG_LEVEL") or "INFO"
 LOG_LEVEL = str(LOG_LEVEL).upper()
+LOG_LEVEL = "DEBUG" if LOG_LEVEL == "TRACE" else LOG_LEVEL
 timestamper = structlog.processors.TimeStamper(fmt="%Y-%m-%d %H:%M:%S")
 log_file_dir = os.path.join(os.getenv("STONEWAVE_HOME", "/tmp"), "logs", "py_table_funcs")
 pathlib.Path(log_file_dir).mkdir(parents=True, exist_ok=True)
