@@ -1,11 +1,14 @@
 import pyarrow as pa
-from multiprocessing.resource_tracker import unregister
 
 from stonewave.sql.udtfs.table_writer import TableWriter
 from stonewave.sql.udtfs.logger import logger
-from stonewave.sql.udtfs.protocol.fsm.shared_record_batch_reader import read_record_batch
+from stonewave.sql.udtfs.protocol.fsm.shared_record_batch_reader import (
+    read_record_batch,
+)
 from stonewave.sql.udtfs.protocol.fsm.apply import _lateral_join, _get_row
-from stonewave.sql.udtfs.protocol.fsm.apply.equal_length_apply import _equal_length_apply
+from stonewave.sql.udtfs.protocol.fsm.apply.equal_length_apply import (
+    _equal_length_apply,
+)
 from stonewave.sql.udtfs.protocol.fsm.apply.apply_left_table_builder import (
     ApplyLeftTableBuilder,
 )
