@@ -7,8 +7,8 @@ from stonewave.sql.udtfs.logger import logger
 class ApplyFunctionFsm(BaseFunctionFsm):
     states = ["start", "wait_for_next", "end"]
 
-    def __init__(self, func, batch_sender):
-        BaseFunctionFsm.__init__(self, func, batch_sender)
+    def __init__(self, func, batch_sender, respond):
+        BaseFunctionFsm.__init__(self, func, batch_sender, respond)
         self.result = None
         self.machine = Machine(model=self, states=ApplyFunctionFsm.states, initial="start")
 
@@ -35,22 +35,24 @@ class ApplyFunctionFsm(BaseFunctionFsm):
 
         self.machine.add_transition(trigger="end", source="*", dest="end", before="end_evaluation")
 
-    def apply_params(self, params, respond):
+    def apply_params(self, params):
         apply_op = ApplyOperator(self.func, params)
         self.result = apply_op.execute()
-        self.send_next_batch(params, respond)
+        self.send_next_batch(params)
 
-    def send_next_batch(self, params, respond):
+    def send_next_batch(self, params):
         try:
             batch = next(self.result)
-            self._batch_sender.send(batch, respond)
-        except StopIteration:
-            respond("end")
 
-    def end_evaluation(self, params, respond):
+            result_batch = self._batch_sender.send(batch)
+            self._respond(result_batch)
+        except StopIteration:
+            self._respond("end")
+
+    def end_evaluation(self, params, result=None):
         logger.debug("end apply func")
+        self._respond(result or "finish", state="finish")
         self._clean_up()
-        respond("finish")
 
     def _clean_up(self):
         self.result = None
