@@ -9,8 +9,8 @@ from stonewave.sql.udtfs.protocol.fsm.base_function_fsm import BaseFunctionFsm
 class EvalFunctionFsm(BaseFunctionFsm):
     states = ["start", "wait_for_next", "end"]
 
-    def __init__(self, func, batch_sender):
-        BaseFunctionFsm.__init__(self, func, batch_sender)
+    def __init__(self, func, batch_sender, respond):
+        BaseFunctionFsm.__init__(self, func, batch_sender, respond)
         self._row_writer = TableWriter()
         self._is_evaluated = False
 
@@ -32,10 +32,10 @@ class EvalFunctionFsm(BaseFunctionFsm):
 
         self.machine.add_transition(trigger="end", source="*", dest="end", before="end_evaluation")
 
-    def eval_params(self, params, respond):
-        self.send_next_batch(params, respond)
+    def eval_params(self, params):
+        self.send_next_batch(params)
 
-    def send_next_batch(self, params, respond):
+    def send_next_batch(self, params):
         if not self._is_evaluated:
             self.func.initialize(self._row_writer)
             func_name = self.func.get_name()
@@ -56,15 +56,16 @@ class EvalFunctionFsm(BaseFunctionFsm):
 
         batch = self._row_writer.flush(True)
         if batch is not None:
-            self._batch_sender.send(batch, respond)
+            result_batch = self._batch_sender.send(batch)
+            self._respond(result_batch)
             return
         else:
-            self.end(params, respond)
+            self.end(params)
 
-    def end_evaluation(self, params, respond):
+    def end_evaluation(self, params, result=None):
         logger.debug("end func evaluation")
+        self._respond(result or "finish", state="finish")
         self._clean_up()
-        respond("finish")
 
     def _clean_up(self):
         self._row_writer = None
