@@ -2,7 +2,7 @@ import pyarrow as pa
 from multiprocessing import shared_memory
 from multiprocessing.resource_tracker import unregister
 from stonewave.sql.udtfs.protocol.shared_memory_record_batch_reader import (
-    SharedMemoryRecordBatchReader,
+    ThreadLocalSharedMemoryObjects,
 )
 
 
@@ -27,7 +27,7 @@ def share_record_batch(record_batch):
     data_size = _get_batch_data_size(record_batch)
     shm = shared_memory.SharedMemory(create=True, size=data_size)
     _write_batch_to_buf(record_batch, pa.py_buffer(shm.buf))
-    SharedMemoryRecordBatchReader.shared_memory_objects.append(shm)
+    ThreadLocalSharedMemoryObjects.stash(shm)
 
     shm.close()
     # FIXME: we don't need to unregister shared memory and requires this Python process to outlive C++ process if Python fixes it
