@@ -1,6 +1,9 @@
 import pyarrow as pa
 from stonewave.sql.udtfs.logger import logger
-from stonewave.sql.udtfs.union_type_resolver import primitive_union_data_type, build_primitive_union_column
+from stonewave.sql.udtfs.union_type_resolver import (
+    primitive_union_data_type,
+    build_primitive_union_column,
+)
 
 
 class RecordBatchBuilder(object):
@@ -71,6 +74,7 @@ class RecordBatchBuilder(object):
         and return None if the built record batch is empty.
         """
         if self.columns:
+            self.fill_equal_length_for_all_builders(self._current_process_row_count)
             logger.debug(
                 "flushing contents from record batch builder",
                 columns=len(self.columns),
