@@ -34,5 +34,7 @@ def build_primitive_union_column(column_values):
             column_values.pop(i)
         child_arrays.append(pa.array(child_array, type=type_tuple[1]))
     return pa.UnionArray.from_dense(
-        pa.array(type_ids, type=pa.int8()), pa.array(offsets, type=pa.int32()), child_arrays
+        pa.array(type_ids, type=pa.int8()),
+        pa.array(offsets, type=pa.int32()),
+        child_arrays,
     )
