@@ -3,7 +3,7 @@ from stonewave.sql.udtfs.constants import ParameterDataType as pdt
 
 
 def get_arrow_data_type_from_value(value):
-    if not value:
+    if value is None:
         return pa.utf8()
     else:
         # bool needs to be placed before int because isinstance(True, int) == True
